pub struct VassalsSettings {
pub vassal_reward_script: String,
pub suzerain_reward_script: String,
pub vassal_shield_duration_secs: i64,
}Fields
vassal_reward_script: Stringsuzerain_reward_script: Stringvassal_shield_duration_secs: i64Trait Implementations
Sourceimpl Clone for VassalsSettings
impl Clone for VassalsSettings
Sourcefn clone(&self) -> VassalsSettings
fn clone(&self) -> VassalsSettings
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VassalsSettings
impl Debug for VassalsSettings
Sourceimpl<'de> Deserialize<'de> for VassalsSettings
impl<'de> Deserialize<'de> for VassalsSettings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for VassalsSettings
impl JsonSchema for VassalsSettings
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for VassalsSettings
impl Serialize for VassalsSettings
Sourceimpl Tsify for VassalsSettings
impl Tsify for VassalsSettings
const DECL: &'static str = "export interface VassalsSettings {\n vassal_reward_script: string;\n suzerain_reward_script: string;\n vassal_shield_duration_secs: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>